%%This is the file for the methodology chapter:
%%A Demonstration on Solving and Estimating DSGE Models
%%By Ben Wang
%%@MQ 8/12/2010


%write_latex_dynamic_model;
%********************************************************************
var
%********************************************************************

y         % output
pi        % inflation
a;        % technology

%********************************************************************
varexo
%********************************************************************

eps_a              % technology shock
eps_r;             % monetary policy shock


%********************************************************************
parameters
%********************************************************************

beta theta sigmaL alpha rho_a kappa_pi kappa_y;

%beta = 0.98;
%theta = 0.65;
%sigmaL = 1;
%alpha = 0.3;
%rho_a = 0.9;
%kappa_pi = 0.8;
%kappa_y = 0.3;

beta = 0.98;
theta = 0.65;
sigmaL = 1;
alpha = 0.4;
rho_a = 0.9;
kappa_pi = 1.2;
kappa_y = 1.5;

%********************************************************************
Model(linear);
%********************************************************************

%Define reduced parameter that can be used for estimation
# xi_y = ((1-beta*theta)*(1-theta)*alpha/(theta*(sigmaL + alpha)));
# xi_a = ((1-beta*theta)*(1-theta)*sigmaL/(theta*(sigmaL + alpha)));

%Dynamic IS curve:
y = y(+1) - kappa_pi*pi - kappa_y*y - eps_r;

%NKPC:
pi = beta*pi(+1) + xi_y*y + xi_a*a;

%Technology
a = rho_a*a(-1) + eps_a;

end;


%********************************************************************
initval;
%********************************************************************

y = 0;
pi= 0;
a = 0;

end;


%********************************************************************
%shocks;
%********************************************************************

%var eps_a; stderr 1;
%var eps_r; stderr 1;

%end;


%********************************************************************
%steady;
%check;
%stoch_simul(periods = 2000,irf = 50);

%********************************************************************
varobs pi y;
estimated_params;
%********************************************************************
%theta, 0.65;
%beta, 0.98;
%sigmaL, 1;
%alpha, 0.4;
rho_a, 0.9;
%kappa_pi, 1.2;
%kappa_y, 1.5;
stderr eps_a, 0.05;
stderr eps_r, 0.05;
end;

estimation(datafile = Meth_Chap_data);




