function [ likelihood ] = likelihood(X0,param_fix, kalman_init, VarObs)
%LIKELIHOOD:
%Evaluate the log-likelihood function given data. 
%Likelihood first takes the initial guess of the structural parameters as
%given, evaluate them and solve the rational expectation in Model_Info.m.
%Then call kalman filter to estimate the state variable and also evluate
%the likelihood of the data conditional on the initial guess of the
%parameter and the estimated state series associated with the guess. The
%log-likelihood in each period are then summed up to give the objective
%function for maximum likelihood estimation.
%
% Author: Ben Wang
% @Macquarie University, Sydney
% File created:  08/03/2011

%------------- BEGIN CODE --------------

%unpack the initial value
param_init.rho_a = X0(1,1);

%% Call Model_Info.m to solve and load model information
[F, V, H, W] = Model_Info(param_init,param_fix);

%Setup intial condition for the state variable X:
Init_mean = kalman_init.mean;
Init_variance = kalman_init.variance;

var_eps_a = X0(2,1);
var_eps_r = X0(3,1);

%% Perform Kalman filter using my kalman.m
[~, ~, ~, ~, ~, loglik] = ...
   Kalman(VarObs, F,V,H,W, Init_mean, Init_variance, var_eps_a, var_eps_r);

%[LIK, loglik] = kalman_filter(F,V,var_eps_a,var_eps_r,Init_variance,VarObs,1,2);

%Calulate the minus of log-likelihood:
likelihood = -sum(loglik);
end